@@ -26,7 +26,7 @@
 #	include <config.h>
 #endif
 
-#include <ntqwidget.h>
+#include <tqwidget.h>
 #include "global.h"
 
 //	forward class definitions
