@@ -27,7 +27,7 @@
 #	include <config.h>
 #endif
 
-#include <ntqscrollview.h>
+#include <tqscrollview.h>
 
 //	forward class definitions
 //	=========================
