@@ -27,7 +27,7 @@
 #	include <config.h>
 #endif
 
-#include <ntqstringlist.h>
+#include <tqstringlist.h>
 #include <tdemainwindow.h>
 #include "global.h"
 
