@@ -20,11 +20,11 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <ntqbuttongroup.h>
-#include <ntqcheckbox.h>
-#include <ntqlayout.h>
-#include <ntqlineedit.h>
-#include <ntqpushbutton.h>
+#include <tqbuttongroup.h>
+#include <tqcheckbox.h>
+#include <tqlayout.h>
+#include <tqlineedit.h>
+#include <tqpushbutton.h>
 
 #include <tdeconfig.h>
 #include <kdebug.h>
