@@ -28,11 +28,11 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#include <ntqfile.h>
-#include <ntqlayout.h>
-#include <ntqpushbutton.h>
-#include <ntqstringlist.h>
-#include <ntqtimer.h>
+#include <tqfile.h>
+#include <tqlayout.h>
+#include <tqpushbutton.h>
+#include <tqstringlist.h>
+#include <tqtimer.h>
 
 #include <tdeapplication.h>
 #include <tdeconfig.h>
